@@ -1,5 +1,5 @@
 /*
- * $Id: getcolor.h,v 1.10 2010/10/06 00:19:50 sfeam Exp $
+ * $Id: getcolor.h,v 1.11 2012/10/30 04:43:42 sfeam Exp $
  */
 
 /* GNUPLOT - getcolor.h */
@@ -43,6 +43,9 @@ void rgb1maxcolors_from_gray __PROTO(( double gray, rgb_color *color ));
 void rgb255maxcolors_from_gray __PROTO(( double gray, rgb255_color *rgb255 ));
 double quantize_gray __PROTO(( double gray ));
 
+/* HSV --> RGB user-visible function hsv2rgb(h,s,v) */
+unsigned int hsv2rgb __PROTO(( rgb_color *color ));
+
 /* used to (de-)serialize color/gradient information */
 char *gradient_entry_to_str __PROTO(( gradient_struct *gs ));
 void str_to_gradient_entry __PROTO(( char *s, gradient_struct *gs ));
